@@ -1,5 +1,5 @@
 from flask import ( Blueprint,request,url_for,jsonify,render_template )
-import worker
+from . import worker
 
 bp = Blueprint('index',__name__,url_prefix='/')
 
